#  Copyright (c) 2023 Robert Bosch Manufacturing Solutions GmbH
#
#  See the AUTHORS file(s) distributed with this work for additional
#  information regarding authorship.
#
#  This Source Code Form is subject to the terms of the Mozilla Public
#  License, v. 2.0. If a copy of the MPL was not distributed with this
#  file, You can obtain one at https://mozilla.org/MPL/2.0/.
#
#   SPDX-License-Identifier: MPL-2.0

from rdflib.term import Node

from esmf_aspect_meta_model_python.base.characteristics.quantifiable.quantifiable import Quantifiable
from esmf_aspect_meta_model_python.impl.characteristics.quantifiable.default_quantifiable import DefaultQuantifiable
from esmf_aspect_meta_model_python.loader.instantiator_base import InstantiatorBase
from esmf_aspect_meta_model_python.vocabulary.SAMMC import SAMMC


class QuantifiableInstantiator(InstantiatorBase[Quantifiable]):
    def _create_instance(self, element_node: Node) -> Quantifiable:
        meta_model_base_attributes = self._get_base_attributes(element_node)
        data_type = self._get_data_type(element_node)
        unit = self._get_child(element_node, self._sammc.get_urn(SAMMC.unit))

        if data_type is None:
            raise TypeError("Data type can't be None.")

        return DefaultQuantifiable(meta_model_base_attributes, data_type, unit)
